#! /bin/sh
#
# patchymf.sh release 1.40
# by ITO Takayuki <yuki@fsinet.or.jp>
# http://hp.vector.co.jp/authors/VA001240/
#
# This script applies patch to BeOS R4.5.x YMF724 driver
# for use with some other Yamaha PCI audio chipsets
# and installs it to appropriate place.
#
# 1.00	first release
# 1.10	R4.5 experimental driver supported
# 1.20	R4.5.2 driver supported
# 1.30	YMF754 supported (untested)
# 1.40	Independent of driver version
#	GUI
#
# Get YMF724F specifications at:
# http://www.yamahayst.com/pcaudio/products.htm
#
# PCI vendor ID: 1073h (Yamaha)
# PCI device IDs:
# YMF724D (DS-1)  0004h
# YMF724F (DS-1)  000Dh
# YMF740C (DS-1L) 000Ch
# YMF744B (DS-1S) 0010h
# YMF754  (DS-1E) 0012h

SRCDIR=/system/add-ons/kernel/drivers
DSTDIR=$HOME/config/add-ons/kernel/drivers
FILE=ymf724

cd `dirname $0`

alert --warning "This script will apply patch to the ymf724 driver for use with other Yamaha chipsets." OK Quit > /dev/null
if [ $? -eq 1 ]
then
	alert --stop "Aborted."
	exit 1
fi

if [ ! -f ./bsubst ]
then
	alert --stop "bsubst is missing."
	exit 1
fi

# check original driver

if [ ! -f $SRCDIR/bin/$FILE ]
then
	alert --stop "Original driver $SRCDIR/bin/$FILE not present."
	exit 1
fi

# check parameters

alert --warning "Choose your chipset" YMF724F YMF744B Others > /dev/null
case $? in
0)
	CHIP=ymf724f;;
1)
	CHIP=ymf744b;;
2)
	alert --warning "Choose your chipset" YMF740C YMF754 Others > /dev/null
	case $? in
	0)
		CHIP=ymf740c;;
	1)
		CHIP=ymf754;;
	2)
		alert --stop "Excuse me but I don't yet support your chipset. Let me know the Card ID shown in Devices preference."
		exit 1
		;;
	esac
	;;
esac

SRC="73 10 04 00"
case $CHIP in
ymf724d)
	DST="73 10 04 00";;
ymf724f)
	DST="73 10 0d 00";;
ymf740c)
	DST="73 10 0c 00";;
ymf744b)
	DST="73 10 10 00";;
ymf754)
	DST="73 10 12 00";;
*)
	alert --stop "Unknown chipset: $CHIP"
	exit 1
esac

# apply patch to driver

if [ -f $DSTDIR/bin/$CHIP ]
then
	alert --stop "Patch is already applied."
	exit 1
fi

echo "Processing $SRCDIR/bin/$FILE."
./bsubst "$SRC" "$DST" < $SRCDIR/bin/$FILE > $DSTDIR/bin/$CHIP
cmp -s $SRCDIR/bin/$FILE $DSTDIR/bin/$CHIP
if [ $? -eq 0 ]
then
	alert --stop "Patch is not applicable. Nothing altered."
	rm $DSTDIR/bin/$CHIP
	exit 1
fi

mkdir -p $DSTDIR/dev/audio/old
[ -h $DSTDIR/dev/audio/old/$CHIP ] || \
ln -s ../../../bin/$CHIP $DSTDIR/dev/audio/old/$CHIP

alert --info "Done. Reboot and your card will work."
exit 0
